@@ -10,17 +10,17 @@
 
 #include "mapchooser.h"
 
-#include <klocale.h>
-#include <kglobal.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <kstandarddirs.h>
 #include <klistwidgetsearchline.h>
 
+#include <qdir.h>
 #include <qimage.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlistwidget.h>
-#include <qpainter.h>
+#include <qdialogbuttonbox.h>
+#include <qpushbutton.h>
 
 #include "settings.h"
 
@@ -29,41 +29,54 @@ bool myLessThan(const QString &s1, const QString &s2)
 	return s1.localeAwareCompare(s2) < 0;
 }
 
-mapChooser::mapChooser(QWidget *parent) : KDialog(parent)
+mapChooser::mapChooser(QWidget *parent) : QDialog(parent)
 {
-	setCaption(i18n("Choose Map to Use"));
-	setButtons(KDialog::Ok | KDialog::Cancel);
+	setWindowTitle(i18n("Choose Map to Use"));
 
-	QWidget *mainHB;
-	QHBoxLayout *mainHBLayout;
-	QVBoxLayout *listFilterLayout;
-	QStringList list;
-	KGmap *m;
-	KListWidgetSearchLine *line;
+	QVBoxLayout *mainLayout = new QVBoxLayout();
 
-	mainHB = new QWidget(this);
-	mainHBLayout = new QHBoxLayout(mainHB);
-	mainHBLayout -> setMargin(0);
-	mainHBLayout -> setSpacing(KDialog::spacingHint());
-	list = KGlobal::dirs() -> findAllResources("appdata", "*.kgm");
-	p_listBox = new QListWidget(mainHB);
-	line = new KListWidgetSearchLine(mainHB, p_listBox);
-	line->setClickMessage(i18n("Filter Maps"));
-	listFilterLayout = new QVBoxLayout();
-	listFilterLayout -> setMargin(0);
-	listFilterLayout -> setSpacing(KDialog::spacingHint());
-	mainHBLayout -> addLayout(listFilterLayout);
-	listFilterLayout -> addWidget(line);
+	QHBoxLayout *horizontalLayout = new QHBoxLayout();
+
+	QVBoxLayout *listFilterLayout = new QVBoxLayout();
+	p_listBox = new QListWidget();
+	KListWidgetSearchLine *searchLine = new KListWidgetSearchLine(this, p_listBox);
+	searchLine->setPlaceholderText(i18n("Filter Maps"));
+	listFilterLayout -> addWidget(searchLine);
 	listFilterLayout -> addWidget(p_listBox);
-	QStringList::iterator it;
+
+	horizontalLayout->addLayout(listFilterLayout);
+
+	p_imageContainer = new QLabel();
+	p_imageContainer -> setFixedSize(300, 225);
+	p_imageContainer -> setAlignment(Qt::AlignCenter);
+	horizontalLayout -> addWidget(p_imageContainer);
+
+	mainLayout->addLayout(horizontalLayout);
+
+	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok
+									 | QDialogButtonBox::Cancel);
+	connect(buttonBox, &QDialogButtonBox::accepted, this, &mapChooser::accept);
+	connect(buttonBox, &QDialogButtonBox::rejected, this, &mapChooser::reject);
+	mainLayout->addWidget(buttonBox);
+
+	QSet<QString> list;
+	const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, "", QStandardPaths::LocateDirectory);
+	Q_FOREACH (const QString &dir, dirs)
+	{
+		const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.kgm"));
+		Q_FOREACH (const QString &file, fileNames)
+		{
+			list <<dir + '/' + file;
+		}
+	}
 	QStringList texts;
 	QSet<QString> alreadySeens;
 	QStringList errorTexts;
 	QString lastMapFile = kgeographySettings::self() -> lastMap();
 	QString stringToSelect;
-	for(it = list.begin(); it != list.end(); ++it)
+	KGmap *m;
+	foreach(const QString &mapFilename, list)
 	{
-		QString mapFilename = *it;
 		m = p_reader.parseMap(mapFilename);
 		if (!m)
 		{
@@ -89,20 +102,14 @@ mapChooser::mapChooser(QWidget *parent) : KDialog(parent)
 	{
 		KMessageBox::errorList(this, i18n("Error parsing"), errorTexts);
 	}
+
+	connect(p_listBox, &QListWidget::currentTextChanged, this, &mapChooser::putImage);
+	connect(p_listBox, &QListWidget::itemActivated, this, &mapChooser::accept);
 	
-	p_image = new QLabel(mainHB);
-	p_image -> setFixedSize(300, 225);
-	p_image -> setAlignment(Qt::AlignCenter);
-	mainHBLayout -> addWidget(p_image);
-	
-	connect(p_listBox, SIGNAL(currentTextChanged(const QString&)), this, SLOT(putImage(const QString&)));
-	connect(p_listBox, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(accept()));
-	
-	setMainWidget(mainHB);
 	qSort(texts.begin(), texts.end(), myLessThan);
 	foreach(const QString &text, texts) p_listBox -> addItem(text);
 	if (p_listBox -> count() == 0)
-		enableButtonOk(false);
+		buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
 	else {
 		QList<QListWidgetItem *> itemsWhere = p_listBox->findItems(stringToSelect, Qt::MatchExactly);
 		if ( itemsWhere.size() > 0 )
@@ -110,6 +117,9 @@ mapChooser::mapChooser(QWidget *parent) : KDialog(parent)
 		else
 			p_listBox -> setCurrentRow(0);
 	}
+
+	setLayout(mainLayout);
+
 	p_listBox -> setFocus();
 }
 
@@ -132,7 +142,7 @@ void mapChooser::putImage(const QString &mapName)
 	m = p_maps[mapName];
 	QImage image(m -> getMapFile());
 	image = image.scaled(300, 225, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-	p_image -> setPixmap( QPixmap::fromImage(image) );
+	p_imageContainer -> setPixmap( QPixmap::fromImage(image) );
 }
 
-#include "mapchooser.moc"
+
